============
Installation
============

At the command line::

    $ easy_install infoblox-client

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv infoblox-client
    $ pip install infoblox-client
